\name{analyzeIntronRetention}
\alias{analyzeIntronRetention}
\title{
Detection of Intron Retion(s)
}
\description{
This function utilize the analysis of alternative splicing implemented in the \code{spliceR} package's spliceR function (see ?spliceR::spliceR) to detect whether an isoform contain intron retentions when compared to the hypothetical pre-RNA generated by combining all the exons within a gene. Here an intron retention is defined as when one exon of an isoform overlaps two seperate exons in the hypothetical pre-RNA.
}
\usage{
analyzeIntronRetention(
    switchAnalyzeRlist,
    onlySwitchingGenes=TRUE,
    alpha=0.05,
    dIFcutoff = 0.1,
    showProgress=TRUE,
    quiet=FALSE
)
}
\arguments{
  \item{switchAnalyzeRlist}{
A \code{switchAnalyzeRlist} object.
}
  \item{onlySwitchingGenes}{
A logic indicating whether to only analyze genes with isoform switches (as indicated by the \code{alpha} and \code{dIFcutoff} parameters). Default is FALSE.
}
  \item{alpha}{
The Cutoff used on the FDR correct p-values (q-values) for calling significance. Default is 0.05.
}

\item{dIFcutoff}{
Cutoff used for minimum changes in (absolute) isoform usage before an isoform is considered eligible for switch testing. This cutoff can remove cases where isoforms with extremely low IF values are deemed significant and thereby included in the downstream analysis. This cutoff is analogous to having a (log2) fold change in a normal differential expression analysis of genes to ensure the DE genes have a certain effect size. Default is 0.1 (10\%).
}

\item{showProgress}{
A logic indicating whether to make a progress bar (if TRUE) or not (if FALSE). Default is TRUE.
}
\item{quiet}{ A logic indicating whether to avoid printing progress messages. Default is FALSE}
}

\value{
A \code{switchAnalyzeRlist} where the collumn \code{IR} indicating the number of Intron Retentions found in each transcript have been added to the \code{isoform_features} entry. NA is used if the transcript was not analyzed. Furthermore a data.frame (called 'intronRetentionAnalysis') containing the number of intron retentions as well as the genomic coordinates of these for each isoform_id, is added to the \code{switchAnalyzeRlist}.
}

\references{
\itemize{
        \item{Vitting-Seerup et al. The Landscape of Isoform Switches in Human Cancers. Mol. Cancer Res. (2017).}
        \item{Vitting-Seerup K, et al: spliceR: an R package for classification of alternative splicing and prediction of coding potential from RNA-seq data. BMC Bioinformatics 2014, 15:81.}
}
}

\author{
Kristoffer Vitting-Seerup
}
\seealso{
\code{\link{switchAnalyzeRlist}}\cr
\code{\link{isoformSwitchTest}}\cr
\code{\link{analyzeSwitchConsequences}}
}
\examples{
### Load data
data("exampleSwitchListIntermediary")

### Perform analysis
exampleSwitchListAnalyzed <- analyzeIntronRetention(exampleSwitchListIntermediary, quiet=TRUE)

### Inspect result
head(exampleSwitchListAnalyzed$intronRetentionAnalysis) # the first 6 does not have any intron retentions (IR)
table(exampleSwitchListAnalyzed$intronRetentionAnalysis$IR) # there appear to be 7 transcripts that have an intron retention
}
